@@ -1,6 +1,7 @@
 from . import trainers, predictors, models, transforms, stat, utils
 from atomai.models import load_model
+from atomai.utils import datasets
 from .__version__ import version as __version__
 
 __all__ = ['models', 'trainers', 'predictors', 'nets', 'utils', 'transforms',
-           'stat', 'load_model', '__version__']
+           'stat', 'load_model', 'datasets', '__version__']
