@@ -3,9 +3,10 @@ from .ed import (SignalDecoder, SignalED, SignalEncoder, convDecoderNet,
                  convEncoderNet, coord_latent, fcDecoderNet, fcEncoderNet,
                  rDecoderNet, init_imspec_model, init_VAE_nets)
 from .fcnn import Unet, dilnet, SegResNet, ResHedNet, init_fcnn_model
-
+from .gp import fcFeatureExtractor, GPRegressionModel
 __all__ = ['ConvBlock', 'ResBlock', 'ResModule', 'UpsampleBlock', 'DilatedBlock',
            'init_fcnn_model', 'SegResNet', 'Unet', 'ResHedNet', 'dilnet', 'fcEncoderNet',
            'fcDecoderNet',  'convEncoderNet', 'convDecoderNet', 'rDecoderNet',
            'coord_latent', 'load_model', 'load_ensemble', 'init_imspec_model',
-           'init_VAE_nets', 'SignalEncoder', 'SignalDecoder', 'SignalED']
+           'init_VAE_nets', 'SignalEncoder', 'SignalDecoder', 'SignalED',
+           'fcFeatureExtractor', 'GPRegressionModel']
