@@ -131,9 +131,131 @@ class UpsampleBlock(nn.Module):
         return self.conv(x)
 
 
+class ResBlock(nn.Module):
+    """
+    Builds a residual block
+
+    Args:
+        ndim:
+            Data dimensionality (1D or 2D)
+        nb_layers:
+            Number of layers in the block
+        input_channels:
+            Number of input channels for the block
+        output_channels:
+            Number of the output channels for the block
+        kernel_size:
+            Size of convolutional filter (in pixels)
+        stride:
+            Stride of convolutional filter
+        padding:
+            Value for edge padding
+        batch_norm:
+            Add batch normalization to each layer in the block
+        lrelu_a:
+            Value of alpha parameter in leaky ReLU activation
+            for each layer in the block
+    """
+    def __init__(self,
+                 ndim: int,
+                 input_channels: int,
+                 output_channels: int,
+                 kernel_size: Union[Tuple[int], int] = 3,
+                 stride: Union[Tuple[int], int] = 1,
+                 padding: Union[Tuple[int], int] = 1,
+                 batch_norm: bool = True,
+                 lrelu_a: float = 0.01
+                 ) -> None:
+        """
+        Initializes block's parameters
+        """
+        super(ResBlock, self).__init__()
+        if not 0 < ndim < 3:
+            raise AssertionError("ndim must be equal to 1 or 2")
+        conv = nn.Conv2d if ndim == 2 else nn.Conv1d
+        self.lrelu_a = lrelu_a
+        self.batch_norm = batch_norm
+        self.c0 = conv(input_channels,
+                       output_channels,
+                       kernel_size=1,
+                       stride=1,
+                       padding=0)
+        self.c1 = conv(output_channels,
+                       output_channels,
+                       kernel_size=3,
+                       stride=1,
+                       padding=1)
+        self.c2 = conv(output_channels,
+                       output_channels,
+                       kernel_size=3,
+                       stride=1,
+                       padding=1)
+        if batch_norm:
+            bn = nn.BatchNorm2d if ndim == 2 else nn.BatchNorm1d
+            self.bn1 = bn(output_channels)
+            self.bn2 = bn(output_channels)
+
+    def forward(self, x: torch.Tensor) -> torch.Tensor:
+        """
+        Defines forward pass
+        """
+        x = self.c0(x)
+        residual = x
+        out = self.c1(x)
+        if self.batch_norm:
+            out = self.bn1(out)
+        out = F.leaky_relu(out, negative_slope=self.lrelu_a)
+        out = self.c2(out)
+        if self.batch_norm:
+            out = self.bn2(out)
+        out += residual
+        out = F.leaky_relu(out, negative_slope=self.lrelu_a)
+        return out
+
+
+class ResModule(nn.Module):
+    """
+    Stitches multiple convolutional blocks with residual connections together
+
+    Args:
+            ndim: Data dimensionality (1D or 2D)
+            res_depth: Number of residual blocks in a residual module
+            input_channels: Number of filters in the input layer
+            output_channels: Number of channels in the output layer
+            batch_norm: Batch normalization for non-unity layers in the block
+            lrelu_a: value of negative slope for LeakyReLU activation
+    """
+    def __init__(self,
+                 ndim: int,
+                 res_depth: int,
+                 input_channels: int,
+                 output_channels: int,
+                 batch_norm: bool = True,
+                 lrelu_a: float = 0.01
+                 ) -> None:
+        """
+        Initializes module parameters
+        """
+        super(ResModule, self).__init__()
+        res_module = []
+        for i in range(res_depth):
+            input_channels = output_channels if i > 0 else input_channels
+            res_module.append(
+                ResBlock(ndim, input_channels, output_channels,
+                         lrelu_a=lrelu_a, batch_norm=batch_norm))
+        self.res_module = nn.Sequential(*res_module)
+
+    def forward(self, x: torch.Tensor) -> torch.Tensor:
+        """
+        Defines a forward pass
+        """
+        x = self.res_module(x)
+        return x
+
+
 class DilatedBlock(nn.Module):
     """
-    Creates a "pyramid" with dilated convolutional
+    Creates a "cascade" with dilated convolutional
     layers (aka atrous convolutions)
 
     Args:
@@ -203,4 +325,4 @@ class DilatedBlock(nn.Module):
         for conv_layer in self.atrous_module:
             x = conv_layer(x)
             atrous_layers.append(x.unsqueeze(-1))
-        return torch.sum(torch.cat(atrous_layers, dim=-1), dim=-1)
\ No newline at end of file
+        return torch.sum(torch.cat(atrous_layers, dim=-1), dim=-1)
