@@ -95,6 +95,7 @@ class BaseEnsembleTrainer(BaseTrainer):
         self._reset_rng(seed)
         self._reset_weights()
         self._reset_training_history()
+        self._delete_optimizer()
         (X_train, y_train,
          X_test, y_test) = self.preprocess_train_data(
             X_train, y_train, X_test, y_test)
@@ -129,21 +130,20 @@ class BaseEnsembleTrainer(BaseTrainer):
                 peforms some transforms, and returns the transformed tensors.
                 The dimensions of the transformed tensors must be the same as
                 the dimensions of the original ones.
-            **kwargs: Updates kwargs from initial compilation
-                (can be useful for iterative training)
+            **kwargs:
+                Updates kwargs from initial compilation, which can be useful
+                for iterative training.
 
         Returns:
             The last trained model and dictionary with ensemble weights
         """
 
-        batch_seed = kwargs.get("batch_seed")
         self.update_training_parameters(kwargs)
 
         print("Training ensemble models (strategy = 'from_scratch')")
         for i in range(n_models):
             print("\nEnsemble model {}".format(i + 1))
-            if batch_seed is not None:
-                self.kdict["batch_seed"] = i
+            self.kdict["batch_seed"] = i
             model_i = self.train_baseline(
                 X_train, y_train, X_test, y_test, i, augment_fn)
             self.ensemble_state_dict[i] = dc(model_i.state_dict())
@@ -220,6 +220,7 @@ class BaseEnsembleTrainer(BaseTrainer):
                 self.net.load_state_dict(basemodel_state_dict)
             self._reset_rng(i+2)
             self._reset_training_history()
+            self._delete_optimizer()
             self.compile_trainer(  # Note that here we reinitialize optimizer
                 (X_train, y_train, X_test, y_test),
                 batch_seed=i+2, **self.kdict)
@@ -286,14 +287,15 @@ class BaseEnsembleTrainer(BaseTrainer):
         tor = lambda x: torch.from_numpy(x)
         return tor(X), tor(y), tor(X_), tor(y_)
 
-    def save_ensemble_metadict(self) -> None:
+    def save_ensemble_metadict(self, filename: str = None) -> None:
         """
         Saves meta dictionary with ensemble weights and key information about
         model's structure (needed to load it back) to disk
         """
+        fname = self.filename if filename is None else filename
         ensemble_metadict = dc(self.meta_state_dict)
         ensemble_metadict["weights"] = self.ensemble_state_dict
-        torch.save(ensemble_metadict, self.filename + "_ensemble.tar")
+        torch.save(ensemble_metadict, fname + "_ensemble_metadict.tar")
 
 
 class EnsembleTrainer(BaseEnsembleTrainer):
@@ -306,7 +308,10 @@ class EnsembleTrainer(BaseEnsembleTrainer):
             or initialized custom PyTorch model
         nb_classes:
             Number of classes (if any) in the model's output
-    
+        **kwargs:
+            Number of input, output, and latent dimensions
+            for imspec models (in_dim, out_dim, latent_dim)
+
     Example:
 
         >>> # Train an ensemble of Unet-s
@@ -327,7 +332,7 @@ class EnsembleTrainer(BaseEnsembleTrainer):
         """
         self.nb_classes = nb_classes
         if isinstance(model, str):
-            if model in ["Unet", "dilnet"]:
+            if model in ["Unet", "dilnet", "SegResNet", "ResHedNet"]:
                 self.net, self.meta_state_dict = init_fcnn_model(
                     model, self.nb_classes, **kwargs)
                 self.accuracy_fn = accuracy_fn_seg(nb_classes)
@@ -402,11 +407,12 @@ class EnsembleTrainer(BaseEnsembleTrainer):
 
         train_data = self.preprocess_train_data(
             X_train, y_train, X_test, y_test)
-        self.set_data(*train_data)
+        self.set_data(*train_data, **self.kdict)
 
         self._reset_rng(seed)
         self._reset_weights()
         self._reset_training_history()
+        self._delete_optimizer()
 
         self.compile_trainer(
             (X_train, y_train, X_test, y_test), **self.kdict)
